@@ -1,10 +1,10 @@
-from contextualSpellCheck.contextualSpellCheck import ContextualSpellCheck
+from .contextualSpellCheck import ContextualSpellCheck
 import spacy
 
 __all__ = ["ContextualSpellCheck", "add_to_pipe"]
 
 
 def add_to_pipe(nlp, **kwargs):
-    checker = ContextualSpellCheck()
+    checker = ContextualSpellCheck(**kwargs)
     nlp.add_pipe(checker)
     return nlp
